from __future__ import absolute_import

import os
import re
from ansible_toolset.models import *
from ansible_toolset.utils import read_file_contents, ErrorMessage


class VaultManager:
    def __init__(self, ansible):
        self.ansible = ansible

    def is_encrypted(self, filename):
        return self.ansible.is_encrypted_vault(filename)

    def get_content(self, filename):
        if self.is_encrypted(filename):
            return self.ansible.vault_plaintext(filename)
        else:
            return read_file_contents(filename)

    def create(self, filename):
        if self.is_encrypted(filename):
            raise ErrorMessage("Provided file is already encrypted.")

        self.ansible.encrypt_vault(filename)

    def encrypt(self, filename):
        # in case somebody use ansible-vault manually in meantime.
        if self.is_encrypted(filename):
            return
        vault = Vault.get(filename=filename)

        if os.path.getmtime(filename) > vault.mtime:
            self.ansible.encrypt_vault(filename)
        else:
            with open(filename, "w") as handler:
                handler.write(vault.contents)

        Vault.delete().where(Vault.filename==filename).execute()


    def decrypt(self, filename):
        with open(filename, "r") as handler:
            contents = handler.read()

        self.ansible.decrypt_vault(filename)

        vault, _ = Vault.get_or_create(filename=filename)
        vault.contents = contents
        vault.mtime = os.path.getmtime(filename)
        vault.save()


    def is_known(self, filename):
        return Vault.select().where(Vault.filename==filename).exists()

    def list_vaults(self, open=False, closed=False):
        for root, _, files in os.walk("."):
            for basename in files:
                filename = os.path.realpath(os.path.join(root, basename))

                if closed and self.is_encrypted(filename):
                    yield dict(path=filename, state='closed')
                elif open and self.is_known(filename):
                    yield dict(path=filename, state='open')

    def open(self):
        for item in self.list_vaults(closed=True):
            self.decrypt(item["path"])

    def close(self):
        for item in self.list_vaults(open=True):
            self.encrypt(item["path"])

    def list(self):
        return self.list_vaults(open=True, closed=True)

    def grep(self, pattern, use_regex=False):
        regex = re.compile(pattern)

        for item in self.list_vaults(open=True, closed=True):
            short_path = os.path.relpath(item["path"], os.getcwd())
            content = self.get_content(item["path"])

            for index, line in enumerate(content.split("\n")):
                if (use_regex and regex.search(line)) or (not use_regex and pattern in line):
                    yield dict(
                        short_path=short_path,
                        line=line,
                        line_number=index+1
                    )



from __future__ import absolute_import

from ansible_toolset.ansible.base import AnsibleAdapterBase
from ansible_toolset import utils
from ansible.parsing.vault import VaultLib
from ansible.parsing.vault import VaultEditor

class AnsibleAdapter20(AnsibleAdapterBase):
    def init(self):
        self.vault_editor = VaultEditor(self.vault_password)
        self.vault_lib = VaultLib(self.vault_password)

    def is_encrypted_vault(self, filename):
        return self.vault_lib.is_encrypted(utils.read_file_contents(filename))

    def encrypt_vault(self, filename):
        self.vault_editor.encrypt_file(filename)

    def decrypt_vault(self, filename):
        self.vault_editor.decrypt_file(filename)

    def vault_plaintext(self, filename):
        return self.vault_editor.plaintext(filename)



from __future__ import absolute_import

import ansible
from distutils.version import LooseVersion

ansible_version = LooseVersion(ansible.__version__)

if ansible_version >= LooseVersion("2.2.0.0"):
    from ansible_toolset.ansible.version22 import AnsibleAdapter22 as AnsibleAdapter
elif ansible_version >= LooseVersion("2.0.0.0"):
    from ansible_toolset.ansible.version20 import AnsibleAdapter20 as AnsibleAdapter
else:
    raise RuntimeError("This software is intended to be used with Ansible 2.0 or higher.")



from __future__ import absolute_import

import os
from ansible_toolset import consts as C

class ErrorMessage(Exception):
    pass

def read_file_contents(filename):
    with open(filename, "rb") as fh:
        data = fh.read()

    return data


def get_ansible_vault_password():
    password_file = os.getenv(C.ANSIBLE_VAULT_PASSWORD_FILE_ENV)
    if not password_file:
        raise RuntimeError("You must set {} environment variable.".format(C.ANSIBLE_VAULT_PASSWORD_FILE_ENV))

    return read_file_contents(password_file).rstrip('\n')



#!/usr/bin/env python

import pip.download
from pip.req import parse_requirements
from setuptools import setup

setup(
    name='ansible-toolset',
    version='0.6.0',
    description='Useful Ansible toolset',
    url='https://github.com/krzysztof-magosa/ansible-toolset',
    author='Krzysztof Magosa',
    author_email='krzysztof@magosa.pl',
    license='GPLv3',
    packages=[
        'ansible_toolset',
        'ansible_toolset/ansible'
    ],
    scripts=[
        'bin/ats-vault'
    ],
    install_requires=[
        'peewee>=2.8.5'
    ]
)
